'use strict';

const privileges = require.main.require('./src/privileges');
const topics = require.main.require('./src/topics');
const user = require.main.require('./src/user');
const events = require.main.require('./src/events');

const controllers = require.main.require('./src/controllers');
const Middleware = module.exports;

Middleware.ensurePrivilege = async (req, res, next) => {
	if (isNaN(req.params.tid)) {
		throw new Error('[[error:invalid-data]]');
	}

	const cid = await topics.getTopicField(req.params.tid, 'cid');
	const isAdmin = await user.isAdministrator(req.uid);
	const isPrivileged = await privileges.categories.can('buryTopics', cid, req.uid);

	if (isAdmin || isPrivileged) {
		return next();
	}

	controllers.helpers.notAllowed(req, res);
};

Middleware.logBurial = (req, res, next) => {
	setImmediate(next);
	events.log({
		type: 'topic-buried',
		state: req.body.bury,
		uid: req.uid,
		tid: req.params.tid,
		ip: req.ip,
	});
};
